Area

Struct Area 

pub struct Area { /* private fields */ }
A pointer to a region in memory.

Implementations

Source

impl Area

pub fn new(start: Address, item_size: usize, item_count: usize) -> Self

Creates a new area with specified item size (how many 64 bits values describes one element of the area).

pub fn region(start: Address, count: usize) -> Self

A one-sized cell area.

pub fn from(start: Address, end: Address) -> Self

Returns an area enclosing the specified addresses.

pub fn count(&self) -> usize

Returns the number of Addresses distinguished in this area.

pub fn size(&self) -> usize

Returns the number of Words contained in this area.

pub fn is_null(&self) -> bool

Returns true if the size of the area is 0.

pub fn start(&self) -> Address

Returns the first Address of this area.

pub fn end(&self) -> Address

Returns the last Address of this area.

pub fn constraint(&self, pointer: Address) -> Address

Bounds the specified address inside the area, so it is always a valid pointer to this area.

pub fn offset(&self, index: usize) -> usize

Returns the offset of the index-th element.

pub fn next_address(&self, cursor: Address) -> Address

Returns the next constrained address following cursor.